==> fetch.php?media=snfit-2.2.2.tar.gz: snfit-2.2.2/src/hubblemodel.h <==
#ifndef HUBBLEMODEL_H
#define HUBBLEMODEL_H

#include "fittedsn.h"
#include "param.h"
#include "lcmodels.h"

class Cosmology;

class HubbleModel{


 public:
  
  enum Cosmo2Fit {LCDM,FLCDM,FWCDM,FWWPCDM,FWWACDM};  
  // fixed parameters :
  // LCDM : w0=-1,w1=0
  // FLCDM : omegal=1-omegam,w0=-1,w1=0
  // FWCDM : omegal=1-omegam,w1=0
  // FWWPCDM : omegal=1-omegam
  // FWWACDM : omegal=1-omegam
  
 protected:
  
  Cosmo2Fit cosmotype; // the type of cosmology that is fitted
  LcModel lc_model; // SALT1 or SALT2
  bool malmquist_bias_correction; // if true, correct for malmquist bias
  int number_of_galaxy_types ; // 

 public:

  
  double IntrinsicDispersion; // 

  HubbleModel();
  virtual ~HubbleModel() {};

  FitParams hubbleparams; // the fitted parameters
  
  
  Cosmology* GetCosmology() const; // return a general cosmology for this model
  
  virtual void dump() const ;
   virtual double Mag(const FittedSn* sn) const =0;
  virtual double Mprime_(const FittedSn* sn) const =0;
  virtual double Variance(const FittedSn* sn) const =0;
  virtual double Res(const FittedSn* sn) const =0;
  virtual double Weight(const FittedSn* sn) const {return 1./Variance(sn);};
  virtual double Chi2(const FittedSn* sn)  const {double r=Res(sn); return Weight(sn)*r*r;};
  
  virtual void InitParams(); // create if needed and init parameters of the fit
  
  int NbParams();
  double ParamValue(const string &hubbleparamname) const;
  void FixParam(const string &hubbleparamname, double hubbleparamvalue);
  void ReadFixParam(const string file_name);
  void ReadCosmologyAndFixParam(const string file_name);
  void SetParams(const double *p, const int nval) ;
  void SetCosmo2Fit(Cosmo2Fit what) {cosmotype=what;};
  bool SetCosmo2Fit(const string& what);
  Cosmo2Fit GetCosmo2Fit() const {return cosmotype;};
  void CorrectMalmquistBias(bool yon = true) { malmquist_bias_correction = yon;};
  bool DoesCorrectMalmquistBias() const { return malmquist_bias_correction;};
  void DumpCosmo2Fit(ostream &stream) const;
  virtual void DumpModel(ostream &stream) const;
  virtual void ReadModel(const std::string &FileName);
  virtual int NumberOfGalaxyTypes() const {return number_of_galaxy_types;};
  virtual void SetNumberOfGalaxyTypes(int n)  {number_of_galaxy_types=n;};
  LcModel GetLCModel() const {return lc_model;};
};


#endif /*  HUBBLEFLUXMODEL__H */

==> fetch.php?media=snfit-2.4.1.tar.gz: snfit-2.4.2/src/hubblemodel.h <==
#ifndef HUBBLEMODEL_H
#define HUBBLEMODEL_H

#include "fittedsn.h"
#include "param.h"
#include "lcmodels.h"

class Cosmology;

class HubbleModel{


 public:
  
  enum Cosmo2Fit {LCDM,FLCDM,FWCDM,FWWPCDM,FWWACDM};  
  // fixed parameters :
  // LCDM : w0=-1,w1=0
  // FLCDM : omegal=1-omegam,w0=-1,w1=0
  // FWCDM : omegal=1-omegam,w1=0
  // FWWPCDM : omegal=1-omegam
  // FWWACDM : omegal=1-omegam
  
 protected:
  
  Cosmo2Fit cosmotype; // the type of cosmology that is fitted
  LcModel lc_model; // SALT1 or SALT2
  bool malmquist_bias_correction; // if true, correct for malmquist bias
  int number_of_galaxy_types ; // 

 public:

  
  double IntrinsicDispersion; // 

  HubbleModel();
  virtual ~HubbleModel() {};

  FitParams hubbleparams; // the fitted parameters
  
  
  Cosmology* GetCosmology() const; // return a general cosmology for this model
  
  virtual void dump() const ;
   virtual double Mag(const FittedSn* sn) const =0;
  virtual double Mprime_(const FittedSn* sn) const =0;
  virtual double Variance(const FittedSn* sn) const =0;
  virtual double Res(const FittedSn* sn) const =0;
  virtual double Weight(const FittedSn* sn) const {return 1./Variance(sn);};
  virtual double Chi2(const FittedSn* sn)  const {double r=Res(sn); return Weight(sn)*r*r;};
  
  virtual void InitParams(); // create if needed and init parameters of the fit
  
  int NbParams();
  double ParamValue(const std::string &hubbleparamname) const;
  void FixParam(const std::string &hubbleparamname, double hubbleparamvalue);
  void ReadFixParam(const std::string file_name);
  void ReadCosmologyAndFixParam(const std::string file_name);
  void SetParams(const double *p, const int nval) ;
  void SetCosmo2Fit(Cosmo2Fit what) {cosmotype=what;};
  bool SetCosmo2Fit(const std::string& what);
  Cosmo2Fit GetCosmo2Fit() const {return cosmotype;};
  void CorrectMalmquistBias(bool yon = true) { malmquist_bias_correction = yon;};
  bool DoesCorrectMalmquistBias() const { return malmquist_bias_correction;};
  void DumpCosmo2Fit(std::ostream &stream) const;
  virtual void DumpModel(std::ostream &stream) const;
  virtual void ReadModel(const std::string &FileName);
  virtual int NumberOfGalaxyTypes() const {return number_of_galaxy_types;};
  virtual void SetNumberOfGalaxyTypes(int n)  {number_of_galaxy_types=n;};
  LcModel GetLCModel() const {return lc_model;};
};


#endif /*  HUBBLEFLUXMODEL__H */
